@@ -10,15 +10,16 @@ use simpath::{FileType, FoundType, Simpath};
 use tempdir::TempDir;
 use url::Url;
 
+use flowcore::model::function_definition::FunctionDefinition;
+
 use crate::compiler::cargo_build;
 use crate::errors::*;
-use crate::model::function::Function;
 
 /// Compile a function's implementation to wasm and modify implementation to point to the wasm file
 /// Checks the timestamps of the source and wasm files and only recompiles if wasm file is out of date
 pub fn compile_implementation(
     target_dir: &Path,
-    function: &mut Function,
+    function: &mut FunctionDefinition,
     native_only: bool,
     #[cfg(feature = "debugger")] source_urls: &mut HashSet<(Url, Url)>,
 ) -> Result<(PathBuf, bool)> {
@@ -50,7 +51,9 @@ pub fn compile_implementation(
             }
         } else {
             match function.build_type.as_str() {
-                "rust" => cargo_build::run(&source_path, &wasm_destination)?,
+                "rust" => cargo_build::run(&source_path, &wasm_destination)
+                    .chain_err(|| format!("Cargo build of project at '{}' failed",
+                                       source_path.display()))?,
                 _ => bail!(
                     "Unknown build type '{}' for function at '{}'",
                     function.build_type,
@@ -109,10 +112,9 @@ fn run_optional_command(wasm_path: &Path, command: &str, mut args: Vec<String>)
             .args(command_args)
             .stdin(Stdio::inherit())
             .stdout(Stdio::inherit())
-            .stderr(Stdio::inherit())
-            .spawn()?;
+            .stderr(Stdio::inherit());
 
-        let output = child.wait_with_output()?;
+        let output = child.output()?;
 
         match output.status.code() {
             Some(0) | None => fs::rename(&temp_file_path, &wasm_path)?,
@@ -157,7 +159,7 @@ fn optimize_wasm_file_size(wasm_path: &Path) -> Result<()> {
 
    out_dir optionally overrides the destination directory where the wasm should end up
 */
-fn get_paths(target_dir: &Path, function: &Function) -> Result<(PathBuf, PathBuf)> {
+fn get_paths(target_dir: &Path, function: &FunctionDefinition) -> Result<(PathBuf, PathBuf)> {
     let source_url = function.get_source_url().join(function.get_source())?;
 
     let source_path = source_url
@@ -212,11 +214,10 @@ mod test {
     #[cfg(feature = "debugger")]
     use url::Url;
 
-    use flowcore::output_connection::{OutputConnection, Source};
-
-    use crate::model::function::Function;
-    use crate::model::io::IO;
-    use crate::model::route::Route;
+    use flowcore::model::function_definition::FunctionDefinition;
+    use flowcore::model::io::IO;
+    use flowcore::model::output_connection::{OutputConnection, Source};
+    use flowcore::model::route::Route;
 
     use super::{get_paths, run_optional_command};
     use super::out_of_date;
@@ -321,22 +322,22 @@ mod test {
         );
     }
 
-    fn test_function() -> Function {
-        Function::new(
+    fn test_function() -> FunctionDefinition {
+        FunctionDefinition::new(
             "Stdout".into(),
             false,
-            "stdout.rs".to_string(),
+            "test.rs".to_string(),
             "print".into(),
-            vec![],
+            vec![IO::new(vec!("String".into()), Route::default())],
             vec![IO::new(vec!("String".into()), Route::default())],
             Url::parse(&format!(
                 "file://{}/{}",
                 env!("CARGO_MANIFEST_DIR"),
-                "tests/test-functions/stdio/stdout"
+                "tests/test-functions/test/test"
             ))
             .expect("Could not create source Url"),
             Route::from("/flow0/stdout"),
-            Some("tests/test-functions/stdio/stdout".to_string()),
+            Some("tests/test-functions/test/test".to_string()),
             vec![OutputConnection::new(
                 Source::default(),
                 1,
@@ -360,7 +361,7 @@ mod test {
         let target_dir = tempdir::TempDir::new("flow")
             .expect("Could not create TempDir during testing")
             .into_path();
-        let expected_output_wasm = target_dir.join("stdout.wasm");
+        let expected_output_wasm = target_dir.join("test.wasm");
 
         let (impl_source_path, impl_wasm_path) =
             get_paths(&target_dir, &function).expect("Error in 'get_paths'");
@@ -371,9 +372,8 @@ mod test {
                 Path::new(env!("CARGO_MANIFEST_DIR"))
                     .parent()
                     .expect("Error getting Manifest Dir")
-                    .display()
-                    .to_string(),
-                "flowc/tests/test-functions/stdio/stdout.rs"
+                    .display(),
+                "flowc/tests/test-functions/test/test.rs"
             ),
             impl_source_path
                 .to_str()
@@ -393,7 +393,7 @@ mod test {
         let target_dir = tempdir::TempDir::new("flow")
             .expect("Could not create TempDir during testing")
             .into_path();
-        let expected_output_wasm = target_dir.join("stdout.wasm");
+        let expected_output_wasm = target_dir.join("test.wasm");
 
         let (wasm_destination, built) = super::compile_implementation(
             &target_dir,
@@ -416,7 +416,7 @@ mod test {
         let target_dir = tempdir::TempDir::new("flow")
             .expect("Could not create TempDir during testing")
             .into_path();
-        let expected_output_wasm = target_dir.join("stdout.wasm");
+        let expected_output_wasm = target_dir.join("test.wasm");
         let _ = fs::remove_file(&expected_output_wasm);
 
         #[cfg(feature = "debugger")]
@@ -444,7 +444,7 @@ mod test {
         let target_dir = tempdir::TempDir::new("flow")
             .expect("Could not create TempDir during testing")
             .into_path();
-        let expected_output_wasm = target_dir.join("stdout.wasm");
+        let expected_output_wasm = target_dir.join("test.wasm");
         let _ = fs::remove_file(&expected_output_wasm);
 
         #[cfg(feature = "debugger")]
@@ -471,7 +471,7 @@ mod test {
         let target_dir = tempdir::TempDir::new("flow")
             .expect("Could not create TempDir during testing")
             .into_path();
-        let expected_output_wasm = target_dir.join("stdout.wasm");
+        let expected_output_wasm = target_dir.join("test.wasm");
 
         let _ = fs::remove_file(&expected_output_wasm);
         write(&expected_output_wasm, b"file touched during testing")
