@@ -7,11 +7,11 @@ use log::{debug, info};
 use simpath::{FileType, FoundType, Simpath};
 
 use flowcore::lib_provider::Provider;
+use flowcore::model::flow_definition::FlowDefinition;
+use flowcore::model::process::Process::FlowProcess;
 
 use crate::dumper::dump_dot;
 use crate::errors::*;
-use crate::model::flow::Flow;
-use crate::model::process::Process::FlowProcess;
 
 use super::dump_tables;
 
@@ -24,7 +24,7 @@ use super::dump_tables;
 /// use url::Url;
 /// use flowcore::lib_provider::{Provider, MetaProvider};
 /// use flowcore::errors::Result;
-/// use flowclib::model::process::Process::FlowProcess;
+/// use flowcore::model::process::Process::FlowProcess;
 /// use tempdir::TempDir;
 /// use std::collections::HashSet;
 /// use simpath::Simpath;
@@ -48,7 +48,7 @@ use super::dump_tables;
 /// }
 /// ```
 pub fn dump_flow(
-    flow: &Flow,
+    flow: &FlowDefinition,
     target_dir: &Path,
     provider: &dyn Provider,
     dump_files: bool,
@@ -59,7 +59,6 @@ pub fn dump_flow(
         target_dir.display()
     );
     _dump_flow(flow, 0, target_dir, provider, dump_files, dot_files)?;
-    info!("Dump complete");
     Ok(())
 }
 
@@ -82,10 +81,9 @@ pub fn generate_svgs(root_dir: &Path) -> Result<()> {
                 .args(vec!["-Tsvg", "-O", &path.to_string_lossy()])
                 .stdin(Stdio::inherit())
                 .stdout(Stdio::inherit())
-                .stderr(Stdio::inherit())
-                .spawn()?;
+                .stderr(Stdio::inherit());
 
-            let dot_output = dot_child.wait_with_output()?;
+            let dot_output = dot_child.output()?;
             match dot_output.status.code() {
                 Some(0) => {}
                 Some(_) => bail!("`dot` exited with non-zero status code"),
@@ -104,7 +102,7 @@ pub fn generate_svgs(root_dir: &Path) -> Result<()> {
 */
 #[allow(clippy::or_fun_call)]
 fn _dump_flow(
-    flow: &Flow,
+    flow: &FlowDefinition,
     level: usize,
     target_dir: &Path,
     provider: &dyn Provider,
