@@ -13,8 +13,6 @@ pub mod dumper;
 pub mod generator;
 /// Functions to get information about this version of the flowc library
 pub mod info;
-/// Model defines the structures for the different data types in a flow for use in memory
-pub mod model;
 
 /// We'll put our errors in an `errors` module, and other modules in this crate will `use errors::*;`
 /// to get access to everything `error_chain` creates.
