@@ -11,15 +11,16 @@ use std::process::Stdio;
 
 use serial_test::serial;
 use simpath::Simpath;
+use tempdir::TempDir;
 use url::Url;
 
 use flowclib::compiler::{compile, loader};
 use flowclib::generator::generate;
 use flowclib::generator::generate::GenerationTables;
-use flowclib::model::flow::Flow;
-use flowclib::model::process::Process;
-use flowclib::model::process::Process::FlowProcess;
 use flowcore::lib_provider::MetaProvider;
+use flowcore::model::flow_definition::FlowDefinition;
+use flowcore::model::process::Process;
+use flowcore::model::process::Process::FlowProcess;
 
 #[path = "helper.rs"]
 mod helper;
@@ -44,7 +45,7 @@ error_chain! {
 /// the output and comparing it to the expected output.
 
 fn write_manifest(
-    flow: &Flow,
+    flow: &FlowDefinition,
     debug_symbols: bool,
     out_dir: PathBuf,
     test_name: &str,
@@ -58,7 +59,7 @@ fn write_manifest(
         Url::from_file_path(&filename).map_err(|_| "Could not create filename url")?;
 
     let manifest = generate::create_manifest(
-        &flow,
+        flow,
         debug_symbols,
         &out_dir_path,
         tables,
@@ -80,9 +81,9 @@ fn execute_flow(
     filepath: PathBuf,
     test_args: Vec<String>,
     input: String,
-    client_server: bool,
+    separate_processes: bool,
 ) -> (String, String) {
-    let server = if client_server {
+    let server = if separate_processes {
         println!("Starting the 'flowr' server");
         let mut server_command = Command::new("cargo");
         let server_command_args = vec!["run", "--quiet", "-p", "flowr", "--", "-n", "-s"];
@@ -95,7 +96,7 @@ fn execute_flow(
                 .stdout(Stdio::piped())
                 .stderr(Stdio::piped())
                 .spawn()
-                .unwrap(),
+                .expect("Failed to spawn flowc as server"),
         )
     } else {
         None
@@ -104,18 +105,16 @@ fn execute_flow(
     let mut command = Command::new("cargo");
     let mut command_args = vec!["run", "--quiet", "-p", "flowr", "--"];
 
-    if client_server {
+    if separate_processes {
         // start another 'flowr' process in client mode
         command_args.push("-c");
-        command_args.push("-a");
-        command_args.push("localhost");
     } else {
         // when running client_and_server in same process we want to use native libs
         command_args.push("-n");
     }
 
     // Append the file path to the manifest to run to the command line args
-    command_args.push(filepath.to_str().unwrap());
+    command_args.push(filepath.to_str().expect("Could not convert path to string"));
 
     // Append the flow arguments to the end of the command line
     for test_arg in &test_args {
@@ -123,37 +122,38 @@ fn execute_flow(
     }
 
     // spawn the 'flowr' child process
-    let mut child = command
+    let mut runner = command
         .args(command_args)
         .stdin(Stdio::piped())
         .stdout(Stdio::piped())
         .stderr(Stdio::piped())
         .spawn()
-        .unwrap();
+        .expect("Could not spawn flowr child process");
 
     // send it stdin from the "${testname}.stdin" file
-    write!(child.stdin.unwrap(), "{}", input).unwrap();
+    write!(runner.stdin.expect("Could not get stdin"), "{}", input)
+        .expect("Could not write to stdin");
 
     // read it's stdout
     let mut output = String::new();
-    if let Some(ref mut stdout) = child.stdout {
+    if let Some(ref mut stdout) = runner.stdout {
         for line in BufReader::new(stdout).lines() {
-            output.push_str(&format!("{}\n", &line.unwrap()));
+            output.push_str(&format!("{}\n", &line.expect("Could not read line")));
         }
     }
 
     // read it's stderr
     let mut err = String::new();
-    if let Some(ref mut stderr) = child.stderr {
+    if let Some(ref mut stderr) = runner.stderr {
         for line in BufReader::new(stderr).lines() {
-            err.push_str(&format!("{}\n", &line.unwrap()));
+            err.push_str(&format!("{}\n", &line.expect("Coul dnot read line")));
         }
     }
 
     // If a server was started - then kill it
     if let Some(mut server_child) = server {
         println!("Killing 'flowr' server");
-        server_child.kill().unwrap();
+        server_child.kill().expect("Failed to kill server child process");
     }
 
     (output, err)
@@ -163,12 +163,12 @@ fn test_args(test_dir: &Path, test_name: &str) -> Vec<String> {
     let test_args = format!("{}.args", test_name);
     let mut args_file = test_dir.to_path_buf();
     args_file.push(test_args);
-    let f = File::open(&args_file).unwrap();
+    let f = File::open(&args_file).expect("Could not open args file for test");
     let f = BufReader::new(f);
 
     let mut args = Vec::new();
     for line in f.lines() {
-        args.push(line.unwrap());
+        args.push(line.expect("Could not get line to append to"));
     }
     args
 }
@@ -182,32 +182,33 @@ fn load_flow(test_dir: &Path, test_name: &str, search_path: Simpath) -> Process
         &MetaProvider::new(search_path),
         &mut HashSet::<(Url, Url)>::new(),
     )
-    .unwrap()
+    .expect("Could not load process")
 }
 
 fn get(test_dir: &Path, file_name: &str) -> String {
     let mut expected_file = test_dir.to_path_buf();
     expected_file.push(file_name);
-    let mut f = File::open(&expected_file).unwrap();
+    let mut f = File::open(&expected_file).expect("Could not open file");
     let mut buffer = Vec::new();
-    f.read_to_end(&mut buffer).unwrap();
-    String::from_utf8(buffer).unwrap()
+    f.read_to_end(&mut buffer).expect("Could not read from file");
+    String::from_utf8(buffer).expect("Could not convert to String")
 }
 
-fn execute_test(test_name: &str, search_path: Simpath, client_server: bool) {
+fn execute_test(test_name: &str, search_path: Simpath, separate_processes: bool) {
     let mut root_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
     root_dir.pop();
     let test_dir = root_dir.join(&format!("flowc/tests/test-flows/{}", test_name));
 
     if let FlowProcess(ref flow) = load_flow(&test_dir, test_name, search_path) {
-        let tables = compile::compile(flow).unwrap();
-        let out_dir = test_dir.clone();
-        let manifest_path = write_manifest(flow, true, out_dir, test_name, &tables).unwrap();
-
+        let tables = compile::compile(flow).expect("Could not compile flow");
+        let dir =
+            TempDir::new("flow").expect("Could not get temp dir");
+        let manifest_path = write_manifest(flow, true, dir.into_path(), test_name, &tables)
+            .expect("Could not write manifest file");
         let test_args = test_args(&test_dir, test_name);
         let input = get(&test_dir, &format!("{}.stdin", test_name));
         let (actual_stdout, actual_stderr) =
-            execute_flow(manifest_path, test_args, input, client_server);
+            execute_flow(manifest_path, test_args, input, separate_processes);
         let expected_output = get(&test_dir, &format!("{}.expected", test_name));
         assert!(actual_stderr.is_empty(), "{}", actual_stderr);
         assert_eq!(
@@ -288,7 +289,6 @@ fn two_destinations() {
     execute_test("two_destinations", search_path, false);
 }
 
-#[cfg(feature = "distributed")]
 #[test]
 #[serial]
 fn hello_world_client_server() {
